==> owncloud-app-calendar-1%3A1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/ja.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "カレンダー",
    "Individual" : "個人",
    "Group" : "グループ",
    "Resource" : "リソース",
    "Room" : "部屋",
    "Unknown" : "不明",
    "Required" : "必須",
    "Optional" : "オプション",
    "Does not attend" : "出席しない",
    "New event" : "新しいイベント",
    "Attendees" : "参加者",
    "Reminders" : "リマインダー",
    "Repeating" : "繰り返し",
    "When shared show full event" : "共有時にすべてのイベントを表示",
    "When shared show only busy" : "共有時に実行中のみを表示",
    "When shared hide this event" : "共有時にこのイベントを隠す",
    "Please add a title!" : "タイトルを追加してください！",
    "Please select a calendar!" : "カレンダーを選択してください！",
    "Global" : "全般",
    "None" : "なし",
    "Every day" : "毎日",
    "Every week" : "毎週",
    "Every month" : "毎月",
    "Every year" : "毎年",
    "never" : "なし",
    "At time of event" : "イベント時",
    "5 minutes before" : "5分前",
    "10 minutes before" : "10分前",
    "15 minutes before" : "15分前",
    "30 minutes before" : "30分前",
    "1 hour before" : "1 時間前",
    "2 hours before" : "2時間前",
    "Custom" : "カスタム",
    "Audio" : "オーディオ",
    "E Mail" : "Eメール",
    "Pop up" : "ポップアップ",
    "sec" : "秒",
    "min" : "最低",
    "hours" : "時間",
    "days" : "日",
    "week" : "週",
    "Week {number} of {year}" : "{year}の{number} 週",
    "Successfully imported" : "インポートに成功しました",
    "Partially imported, 1 failure" : "不完全なインポート，失敗1",
    "Partially imported, {n} failures" : "不完全なインポート，失敗{n}",
    "Audio alarm" : "オーディオアラーム",
    "Pop-up" : "ポップアップ",
    "E-Mail" : "メール",
    "{type} {time} before the event starts" : "イベント開始の{type} {time} 前",
    "{type} {time} before the event ends" : "イベント終了の{type} {time} 前",
    "{type} {time} after the event starts" : "イベント開始の{type} {time} 後",
    "{type} {time} after the event ends" : "イベント終了の{type} {time} 後",
    "{type} at the event's start" : "{type} イベント開始時",
    "{type} at the event's end" : "{type} イベント終了時",
    "{type} at {time}" : "{type} {time} 時",
    "{calendar} shared by {owner}" : "{owner} が共有中の{calendar} ",
    "Title of the Event" : "イベントのタイトル",
    "starts" : "開始",
    "ends" : "終了",
    "All day Event" : "終日イベント",
    "Location" : "場所",
    "Delete" : "削除",
    "Cancel" : "キャンセル",
    "More ..." : "さらに表示 ...",
    "Create" : "作成",
    "Update" : "アップデート",
    "Close" : "閉じる",
    "Description" : "説明",
    "Export" : "エクスポート",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Today" : "今日",
    "Share Calendar" : "カレンダーを共有する",
    "More" : "もっと見る",
    "Edit" : "編集",
    "group" : "グループ",
    "New Calendar" : "新しいカレンダーを作成",
    "Subscriptions" : "購読",
    "New Subscription" : "新しい購読",
    "Url" : "Url",
    "Edit event" : "イベントを編集",
    "Delete Event" : "イベントを削除",
    "Save Event" : "イベントを保存",
    "Time" : "時刻",
    "Type" : "種類",
    "Relative" : "相対指定",
    "Absolute" : "絶対指定",
    "Repeat" : "繰り返し",
    "times every" : "繰り返し",
    "Add" : "追加",
    "Please add your email address in the personal settings in order to add attendees." : "出席者に追加するにはアカウント設定でメールアドレスを追加してください",
    "from" : "差出人",
    "to" : "宛先",
    "Import Calendars" : "カレンダーのインポート",
    "Import canceled" : "インポートはキャンセルされました",
    "Analyzing calendar" : "カレンダーの解析中",
    "The file contains objects incompatible with the selected calendar" : "指定したカレンダーに互換性のない情報がファイルに含まれています",
    "New calendar" : "新しいカレンダー",
    "Import scheduled" : "スケジュールのインポート",
    "Settings" : "設定",
    "Import calendar" : "カレンダーのインポート",
    "No Calendars selected for import" : "インポートするカレンダーが指定されていません",
    "Primary CalDAV address" : "一番目の CalDAV アドレス",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV アドレス"
},
"nplurals=1; plural=0;");

==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/ja.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "カレンダー",
    "Individual" : "個人",
    "Group" : "グループ",
    "Resource" : "リソース",
    "Room" : "部屋",
    "Unknown" : "不明",
    "Required" : "必須",
    "Optional" : "オプション",
    "Does not attend" : "出席しない",
    "New event" : "新しいイベント",
    "Attendees" : "参加者",
    "Reminders" : "リマインダー",
    "Repeating" : "繰り返し",
    "When shared show full event" : "共有時にすべてのイベントを表示",
    "When shared show only busy" : "共有時に実行中のみを表示",
    "When shared hide this event" : "共有時にこのイベントを隠す",
    "Please add a title!" : "タイトルを追加してください！",
    "Please select a calendar!" : "カレンダーを選択してください！",
    "Global" : "全般",
    "None" : "なし",
    "Every day" : "毎日",
    "Every week" : "毎週",
    "Every month" : "毎月",
    "Every year" : "毎年",
    "never" : "なし",
    "At time of event" : "イベント時",
    "5 minutes before" : "5分前",
    "10 minutes before" : "10分前",
    "15 minutes before" : "15分前",
    "30 minutes before" : "30分前",
    "1 hour before" : "1 時間前",
    "2 hours before" : "2時間前",
    "Custom" : "カスタム",
    "Audio" : "オーディオ",
    "E Mail" : "Eメール",
    "Pop up" : "ポップアップ",
    "sec" : "秒",
    "min" : "最低",
    "hours" : "時間",
    "days" : "日",
    "week" : "週",
    "start" : "開始",
    "Week {number} of {year}" : "{year}の{number} 週",
    "Successfully imported" : "インポートに成功しました",
    "Partially imported, 1 failure" : "不完全なインポート，失敗1",
    "Partially imported, {n} failures" : "不完全なインポート，失敗{n}",
    "Audio alarm" : "オーディオアラーム",
    "Pop-up" : "ポップアップ",
    "E-Mail" : "メール",
    "{type} {time} before the event starts" : "イベント開始の{type} {time} 前",
    "{type} {time} before the event ends" : "イベント終了の{type} {time} 前",
    "{type} {time} after the event starts" : "イベント開始の{type} {time} 後",
    "{type} {time} after the event ends" : "イベント終了の{type} {time} 後",
    "{type} at the event's start" : "{type} イベント開始時",
    "{type} at the event's end" : "{type} イベント終了時",
    "{type} at {time}" : "{type} {time} 時",
    "{calendar} shared by {owner}" : "{owner} が共有中の{calendar} ",
    "Title of the Event" : "イベントのタイトル",
    "starts" : "開始",
    "ends" : "終了",
    "All day Event" : "終日イベント",
    "Delete" : "削除",
    "Cancel" : "キャンセル",
    "More ..." : "さらに表示 ...",
    "Create" : "作成",
    "Update" : "アップデート",
    "Close" : "閉じる",
    "Location" : "場所",
    "Description" : "説明",
    "Export" : "エクスポート",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Today" : "今日",
    "Share Calendar" : "カレンダーを共有する",
    "More" : "もっと見る",
    "Edit" : "編集",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "ユーザーもしくはグループと共有",
    "can edit" : "編集を許可",
    "group" : "グループ",
    "New Calendar" : "新しいカレンダーを作成",
    "Subscriptions" : "購読",
    "New Subscription" : "新しい購読",
    "Url" : "Url",
    "Edit event" : "イベントを編集",
    "Delete Event" : "イベントを削除",
    "Save Event" : "イベントを保存",
    "Time" : "時刻",
    "Type" : "種類",
    "Relative" : "相対指定",
    "Absolute" : "絶対指定",
    "Repeat" : "繰り返し",
    "times every" : "繰り返し",
    "Add" : "追加",
    "Please add your email address in the personal settings in order to add attendees." : "出席者に追加するにはアカウント設定でメールアドレスを追加してください",
    "from" : "差出人",
    "to" : "宛先",
    "Reset repeating rule" : "繰り返し規則のリセット",
    "Repeat every ..." : "繰り返し…",
    "Import Calendars" : "カレンダーのインポート",
    "Import canceled" : "インポートはキャンセルされました",
    "Analyzing calendar" : "カレンダーの解析中",
    "The file contains objects incompatible with the selected calendar" : "指定したカレンダーに互換性のない情報がファイルに含まれています",
    "New calendar" : "新しいカレンダー",
    "Import scheduled" : "スケジュールのインポート",
    "Settings" : "設定",
    "Import calendar" : "カレンダーのインポート",
    "No Calendars selected for import" : "インポートするカレンダーが指定されていません",
    "Primary CalDAV address" : "一番目の CalDAV アドレス",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV アドレス"
},
"nplurals=1; plural=0;");
